@@ -159,9 +159,6 @@ func EnableOrDisableAddon(cc *config.ClusterConfig, name string, val string) err
 
 	// check addon status before enabling/disabling it
 	if isAddonAlreadySet(cc, addon, enable) {
-		if addon.Name() == "gcp-auth" {
-			return nil
-		}
 		klog.Warningf("addon %s should already be in state %v", name, val)
 		if !enable {
 			return nil
@@ -192,7 +189,7 @@ func EnableOrDisableAddon(cc *config.ClusterConfig, name string, val string) err
 		exit.Error(reason.HostSaveProfile, "Failed to persist images", err)
 	}
 
-	if cc.KubernetesConfig.ImageRepository == "registry.cn-hangzhou.aliyuncs.com/google_containers" {
+	if cc.KubernetesConfig.ImageRepository == constants.AliyunMirror {
 		images, customRegistries = assets.FixAddonImagesAndRegistries(addon, images, customRegistries)
 	}
 
@@ -250,7 +247,7 @@ func addonSpecificChecks(cc *config.ClusterConfig, name string, enable bool, run
 	}
 
 	if name == "registry" {
-		if driver.NeedsPortForward(cc.Driver) {
+		if driver.NeedsPortForward(cc.Driver) && driver.IsKIC(cc.Driver) {
 			port, err := oci.ForwardedPort(cc.Driver, cc.Name, constants.RegistryAddonPort)
 			if err != nil {
 				return false, errors.Wrap(err, "registry port")
