@@ -31,8 +31,8 @@ import (
 	"k8s.io/minikube/pkg/minikube/sysinit"
 )
 
-// enableOrDisableAutoPause enables the service after the config was copied by generic enble
-func enableOrDisableAutoPause(cc *config.ClusterConfig, name string, val string) error {
+// enableOrDisableAutoPause enables the service after the config was copied by generic enable.
+func enableOrDisableAutoPause(cc *config.ClusterConfig, name, val string) error {
 	enable, err := strconv.ParseBool(val)
 	if err != nil {
 		return errors.Wrapf(err, "parsing bool: %s", name)
@@ -44,16 +44,18 @@ func enableOrDisableAutoPause(cc *config.ClusterConfig, name string, val string)
 	if enable {
 		if err := sysinit.New(co.CP.Runner).EnableNow("auto-pause"); err != nil {
 			klog.ErrorS(err, "failed to enable", "service", "auto-pause")
+			return err
 		}
 	}
 
-	port := co.CP.Port // api server port
-	if enable {        // if enable then need to calculate the forwarded port
+	port := co.CP.Port // API server port
+	if enable {        // if enable, calculate the forwarded port
 		port = constants.AutoPauseProxyPort
-		if driver.NeedsPortForward(cc.Driver) {
+		if driver.NeedsPortForward(cc.Driver) && driver.IsKIC(cc.Driver) {
 			port, err = oci.ForwardedPort(cc.Driver, cc.Name, port)
 			if err != nil {
 				klog.ErrorS(err, "failed to get forwarded port for", "auto-pause port", port)
+				return err
 			}
 		}
 	}
@@ -64,7 +66,7 @@ func enableOrDisableAutoPause(cc *config.ClusterConfig, name string, val string)
 		return err
 	}
 	if updated {
-		klog.Infof("%s context has been updated to point to auto-pause proxy %s:%s", cc.Name, co.CP.Hostname, co.CP.Port)
+		klog.Infof("%s context has been updated to point to auto-pause proxy %s:%d", cc.Name, co.CP.Hostname, port)
 	} else {
 		klog.Info("no need to update kube-context for auto-pause proxy")
 	}
