@@ -25,8 +25,7 @@ import (
 )
 
 func Test_createDiskImage(t *testing.T) {
-	tmpdir := tests.MakeTempDir()
-	defer tests.RemoveTempDir(tmpdir)
+	tmpdir := tests.MakeTempDir(t)
 
 	sshPath := filepath.Join(tmpdir, "ssh")
 	if err := os.WriteFile(sshPath, []byte("mysshkey"), 0644); err != nil {
