@@ -21,6 +21,7 @@ import (
 	"strings"
 	"testing"
 
+	"github.com/blang/semver/v4"
 	"k8s.io/minikube/pkg/minikube/driver"
 )
 
@@ -55,30 +56,41 @@ func appendVersionVariations(tc []testCase, v []int, reason string) []testCase {
 	return appendedTc
 }
 
+func stringToIntSlice(t *testing.T, s string) []int {
+	sem, err := semver.ParseTolerant(s)
+	if err != nil {
+		t.Fatalf("failed to parse %s to semver: %v", s, err)
+	}
+	return []int{int(sem.Major), int(sem.Minor), int(sem.Patch)}
+}
+
 func TestCheckDockerVersion(t *testing.T) {
+	recParts := stringToIntSlice(t, recommendedDockerVersion)
+	minParts := stringToIntSlice(t, minDockerVersion)
+
 	tc := []testCase{
 		{
 			version: "windows-20.0.1",
 			expect:  "PROVIDER_DOCKER_WINDOWS_CONTAINERS",
 		},
 		{
-			version: fmt.Sprintf("linux-%02d.%02d", minDockerVersion[0], minDockerVersion[1]),
+			version: fmt.Sprintf("linux-%02d.%02d", recParts[0], recParts[1]),
 			expect:  "",
 		},
 		{
-			version: fmt.Sprintf("linux-%02d.%02d.%02d", minDockerVersion[0], minDockerVersion[1], minDockerVersion[2]),
+			version: fmt.Sprintf("linux-%s", recommendedDockerVersion),
 			expect:  "",
 		},
 	}
 
 	for i := 0; i < 3; i++ {
 		v := make([]int, 3)
-		copy(v, minDockerVersion)
+		copy(v, minParts)
 
-		v[i] = minDockerVersion[i] + 1
+		v[i] = minParts[i] + 1
 		tc = appendVersionVariations(tc, v, "")
 
-		v[i] = minDockerVersion[i] - 1
+		v[i] = minParts[i] - 1
 		if v[2] < 0 {
 			// skip test if patch version is negative number.
 			continue
@@ -86,27 +98,39 @@ func TestCheckDockerVersion(t *testing.T) {
 		tc = appendVersionVariations(tc, v, "PROVIDER_DOCKER_VERSION_LOW")
 	}
 
+	recommendedSupported := fmt.Sprintf("Minimum recommended version is %s, minimum supported version is %s", recommendedDockerVersion, minDockerVersion)
+	install := fmt.Sprintf("Install the official release of %s (%s, current version is %%s)", driver.FullName(driver.Docker), recommendedSupported)
+	update := fmt.Sprintf("Upgrade %s to a newer version (%s, current version is %%s)", driver.FullName(driver.Docker), recommendedSupported)
 	tc = append(tc, []testCase{
 		{
 			// "dev" is set when Docker (Moby) was installed with `make binary && make install`
-			version: "linux-dev",
-			expect:  "",
-			expectFixContains: fmt.Sprintf("Install the official release of %s (Minimum recommended version is %02d.%02d.%d, current version is dev)",
-				driver.FullName(driver.Docker), minDockerVersion[0], minDockerVersion[1], minDockerVersion[2]),
+			version:           "linux-dev",
+			expect:            "",
+			expectFixContains: fmt.Sprintf(install, "dev"),
 		},
 		{
 			// "library-import" is set when Docker (Moby) was installed with `go build github.com/docker/docker/cmd/dockerd` (unrecommended, but valid)
-			version: "linux-library-import",
-			expect:  "",
-			expectFixContains: fmt.Sprintf("Install the official release of %s (Minimum recommended version is %02d.%02d.%d, current version is library-import)",
-				driver.FullName(driver.Docker), minDockerVersion[0], minDockerVersion[1], minDockerVersion[2]),
+			version:           "linux-library-import",
+			expect:            "",
+			expectFixContains: fmt.Sprintf(install, "library-import"),
 		},
 		{
 			// "foo.bar.baz" is a triplet that cannot be parsed as "%02d.%02d.%d"
-			version: "linux-foo.bar.baz",
-			expect:  "",
-			expectFixContains: fmt.Sprintf("Install the official release of %s (Minimum recommended version is %02d.%02d.%d, current version is foo.bar.baz)",
-				driver.FullName(driver.Docker), minDockerVersion[0], minDockerVersion[1], minDockerVersion[2]),
+			version:           "linux-foo.bar.baz",
+			expect:            "",
+			expectFixContains: fmt.Sprintf(install, "foo.bar.baz"),
+		},
+		{
+			// "linux-18.09.9" is older than minimum recommended version
+			version:           "linux-18.09.9",
+			expect:            "",
+			expectFixContains: fmt.Sprintf(update, "18.09.9"),
+		},
+		{
+			// "linux-18.06.2" is older than minimum required version
+			version:           "linux-18.06.2",
+			expect:            "PROVIDER_DOCKER_VERSION_LOW",
+			expectFixContains: fmt.Sprintf(update, "18.06.2"),
 		},
 	}...)
 
