@@ -1,5 +1,4 @@
 //go:build integration
-// +build integration
 
 /*
 Copyright 2016 The Kubernetes Authors All rights reserved.
@@ -26,7 +25,6 @@ import (
 	"encoding/json"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"net/http"
 	"net/url"
 	"os"
@@ -51,7 +49,7 @@ import (
 	"github.com/blang/semver/v4"
 	"github.com/elazarl/goproxy"
 	"github.com/hashicorp/go-retryablehttp"
-	"github.com/otiai10/copy"
+	cp "github.com/otiai10/copy"
 	"github.com/phayes/freeport"
 	"github.com/pkg/errors"
 	"golang.org/x/build/kubernetes/api"
@@ -96,7 +94,7 @@ func TestFunctional(t *testing.T) {
 			{"CopySyncFile", setupFileSync},                 // Set file for the file sync test case
 			{"StartWithProxy", validateStartWithProxy},      // Set everything else up for success
 			{"AuditLog", validateAuditAfterStart},           // check audit feature works
-			{"SoftStart", validateSoftStart},                // do a soft start. ensure config didnt change.
+			{"SoftStart", validateSoftStart},                // do a soft start. ensure config didn't change.
 			{"KubeContext", validateKubeContext},            // Racy: must come immediately after "minikube start"
 			{"KubectlGetPods", validateKubectlGetPods},      // Make sure apiserver is up
 			{"CacheCmd", validateCacheCmd},                  // Caches images needed for subsequent tests because of proxy
@@ -143,6 +141,7 @@ func TestFunctional(t *testing.T) {
 			{"MountCmd", validateMountCmd},
 			{"ProfileCmd", validateProfileCmd},
 			{"ServiceCmd", validateServiceCmd},
+			{"ServiceCmdConnect", validateServiceCmdConnect},
 			{"AddonsCmd", validateAddonsCmd},
 			{"PersistentVolumeClaim", validatePersistentVolumeClaim},
 			{"TunnelCmd", validateTunnelCmd},
@@ -481,10 +480,7 @@ func validateDockerEnv(ctx context.Context, t *testing.T, profile string) {
 			defer cancel()
 
 			command := make([]string, len(tc.commandPrefix)+1)
-			// Would use "copy" built-in here, but that is shadowed by "copy" package
-			for i, v := range tc.commandPrefix {
-				command[i] = v
-			}
+			copy(command, tc.commandPrefix)
 
 			formattedArg := fmt.Sprintf(tc.formatArg, Target(), profile)
 
@@ -612,7 +608,7 @@ func validateStartWithProxy(ctx context.Context, t *testing.T, profile string) {
 // validateStartWithCustomCerts makes sure minikube start respects the HTTPS_PROXY environment variable and works with custom certs
 // a proxy is started by calling the mitmdump binary in the background, then installing the certs generated by the binary
 // mitmproxy/dump creates the proxy at localhost at port 8080
-// only runs on Github Actions for amd64 linux, otherwise validateStartWithProxy runs instead
+// only runs on GitHub Actions for amd64 linux, otherwise validateStartWithProxy runs instead
 func validateStartWithCustomCerts(ctx context.Context, t *testing.T, profile string) {
 	defer PostMortemLogs(t, profile)
 	err := startProxyWithCustomCerts(ctx, t)
@@ -767,11 +763,6 @@ func validateExtraConfig(ctx context.Context, t *testing.T, profile string) {
 	if !strings.Contains(afterCfg.Config.KubernetesConfig.ExtraOptions.String(), expectedExtraOptions) {
 		t.Errorf("expected ExtraOptions to contain %s but got %s", expectedExtraOptions, afterCfg.Config.KubernetesConfig.ExtraOptions.String())
 	}
-
-	expectedExtraOptions = "kubelet.housekeeping-interval=5m"
-	if !strings.Contains(afterCfg.Config.KubernetesConfig.ExtraOptions.String(), expectedExtraOptions) {
-		t.Errorf("expected ExtraOptions to contain %s but got %s", expectedExtraOptions, afterCfg.Config.KubernetesConfig.ExtraOptions.String())
-	}
 }
 
 // imageID returns a docker image id for image `image` and current architecture
@@ -1065,10 +1056,7 @@ func validateCacheCmd(ctx context.Context, t *testing.T, profile string) {
 				t.Skipf("docker is not installed, skipping local image test")
 			}
 
-			dname, err := os.MkdirTemp("", profile)
-			if err != nil {
-				t.Fatalf("Cannot create temp dir: %v", err)
-			}
+			dname := t.TempDir()
 
 			message := []byte("FROM scratch\nADD Dockerfile /x")
 			err = os.WriteFile(filepath.Join(dname, "Dockerfile"), message, 0644)
@@ -1247,10 +1235,7 @@ func validateLogsCmd(ctx context.Context, t *testing.T, profile string) {
 
 // validateLogsFileCmd asserts "logs --file" command functionality
 func validateLogsFileCmd(ctx context.Context, t *testing.T, profile string) {
-	dname, err := os.MkdirTemp("", profile)
-	if err != nil {
-		t.Fatalf("Cannot create temp dir: %v", err)
-	}
+	dname := t.TempDir()
 	logFileName := filepath.Join(dname, "logs.txt")
 
 	// docs: Run `minikube logs --file logs.txt` to save the logs to a local file
@@ -1399,6 +1384,14 @@ func validateProfileCmd(ctx context.Context, t *testing.T, profile string) {
 	})
 }
 
+func killContext(cmdContext *exec.Cmd, killDelay time.Duration, t *testing.T) {
+	time.Sleep(killDelay)
+	err := cmdContext.Process.Signal(os.Interrupt)
+	if err != nil {
+		t.Error("Failed to sent interrupt to proc", err)
+	}
+}
+
 // validateServiceCmd asserts basic "service" command functionality
 func validateServiceCmd(ctx context.Context, t *testing.T, profile string) {
 	defer PostMortemLogs(t, profile)
@@ -1460,18 +1453,16 @@ func validateServiceCmd(ctx context.Context, t *testing.T, profile string) {
 		t.Errorf("expected 'service list' to contain *hello-node* but got -%q-", rr.Stdout.String())
 	}
 
+	// docs: Run `minikube service` with `--https --url` to make sure the HTTPS endpoint URL of the service is printed
+	cmdContext := exec.CommandContext(ctx, Target(), "-p", profile, "service", "--namespace=default", "--https", "--url", "hello-node")
 	if NeedsPortForward() {
-		t.Skipf("test is broken for port-forwarded drivers: https://github.com/kubernetes/minikube/issues/7383")
+		go killContext(cmdContext, 2*time.Second, t)
 	}
 
-	// docs: Run `minikube service` with `--https --url` to make sure the HTTPS endpoint URL of the service is printed
-	rr, err = Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "service", "--namespace=default", "--https", "--url", "hello-node"))
-	if err != nil {
+	rr, err = Run(t, cmdContext)
+	if err != nil && !strings.Contains(err.Error(), "interrupt") {
 		t.Fatalf("failed to get service url. args %q : %v", rr.Command(), err)
 	}
-	if rr.Stderr.String() != "" {
-		t.Errorf("expected stderr to be empty but got *%q* . args %q", rr.Stderr, rr.Command())
-	}
 
 	splits := strings.Split(rr.Stdout.String(), "|")
 	var endpoint string
@@ -1491,17 +1482,26 @@ func validateServiceCmd(ctx context.Context, t *testing.T, profile string) {
 		t.Errorf("expected scheme for %s to be 'https' but got %q", endpoint, u.Scheme)
 	}
 
+	cmdContext = exec.CommandContext(ctx, Target(), "-p", profile, "service", "hello-node", "--url", "--format={{.IP}}")
+	if NeedsPortForward() {
+		go killContext(cmdContext, 2*time.Second, t)
+	}
 	// docs: Run `minikube service` with `--url --format={{.IP}}` to make sure the IP address of the service is printed
-	rr, err = Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "service", "hello-node", "--url", "--format={{.IP}}"))
-	if err != nil {
+	rr, err = Run(t, cmdContext)
+	if err != nil && !strings.Contains(err.Error(), "interrupt") {
 		t.Errorf("failed to get service url with custom format. args %q: %v", rr.Command(), err)
 	}
+
 	if strings.TrimSpace(rr.Stdout.String()) != u.Hostname() {
 		t.Errorf("expected 'service --format={{.IP}}' output to be -%q- but got *%q* . args %q.", u.Hostname(), rr.Stdout.String(), rr.Command())
 	}
 
+	cmdContext = exec.CommandContext(ctx, Target(), "-p", profile, "service", "hello-node", "--url")
+	if NeedsPortForward() {
+		go killContext(cmdContext, 2*time.Second, t)
+	}
 	// docs: Run `minikube service` with a regular `--url` to make sure the HTTP endpoint URL of the service is printed
-	rr, err = Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "service", "hello-node", "--url"))
+	rr, err = Run(t, cmdContext)
 	if err != nil {
 		t.Errorf("failed to get service url. args: %q: %v", rr.Command(), err)
 	}
@@ -1517,8 +1517,71 @@ func validateServiceCmd(ctx context.Context, t *testing.T, profile string) {
 	if u.Scheme != "http" {
 		t.Fatalf("expected scheme to be -%q- got scheme: *%q*", "http", u.Scheme)
 	}
+}
 
-	t.Logf("Attempting to fetch %s ...", endpoint)
+func validateServiceCmdConnect(ctx context.Context, t *testing.T, profile string) {
+	defer PostMortemLogs(t, profile)
+
+	defer func() {
+		if t.Failed() {
+			t.Logf("service test failed - dumping debug information")
+			t.Logf("-----------------------service failure post-mortem--------------------------------")
+			ctx, cancel := context.WithTimeout(context.Background(), Minutes(2))
+			defer cancel()
+			rr, err := Run(t, exec.CommandContext(ctx, "kubectl", "--context", profile, "describe", "po", "hello-node-connect"))
+			if err != nil {
+				t.Logf("%q failed: %v", rr.Command(), err)
+			}
+			t.Logf("hello-node pod describe:\n%s", rr.Stdout)
+
+			rr, err = Run(t, exec.CommandContext(ctx, "kubectl", "--context", profile, "logs", "-l", "app=hello-node-connect"))
+			if err != nil {
+				t.Logf("%q failed: %v", rr.Command(), err)
+			}
+			t.Logf("hello-node logs:\n%s", rr.Stdout)
+
+			rr, err = Run(t, exec.CommandContext(ctx, "kubectl", "--context", profile, "describe", "svc", "hello-node-connect"))
+			if err != nil {
+				t.Logf("%q failed: %v", rr.Command(), err)
+			}
+			t.Logf("hello-node svc describe:\n%s", rr.Stdout)
+		}
+	}()
+
+	var rr *RunResult
+	var err error
+	// docs: Create a new `k8s.gcr.io/echoserver` deployment
+	// k8s.gcr.io/echoserver is not multi-arch
+	if arm64Platform() {
+		rr, err = Run(t, exec.CommandContext(ctx, "kubectl", "--context", profile, "create", "deployment", "hello-node-connect", "--image=k8s.gcr.io/echoserver-arm:1.8"))
+	} else {
+		rr, err = Run(t, exec.CommandContext(ctx, "kubectl", "--context", profile, "create", "deployment", "hello-node-connect", "--image=k8s.gcr.io/echoserver:1.8"))
+	}
+
+	if err != nil {
+		t.Fatalf("failed to create hello-node deployment with this command %q: %v.", rr.Command(), err)
+	}
+	rr, err = Run(t, exec.CommandContext(ctx, "kubectl", "--context", profile, "expose", "deployment", "hello-node-connect", "--type=NodePort", "--port=8080"))
+	if err != nil {
+		t.Fatalf("failed to expose hello-node deployment: %q : %v", rr.Command(), err)
+	}
+
+	if _, err := PodWait(ctx, t, profile, "default", "app=hello-node-connect", Minutes(10)); err != nil {
+		t.Fatalf("failed waiting for hello-node pod: %v", err)
+	}
+
+	cmdContext := exec.CommandContext(ctx, Target(), "-p", profile, "service", "hello-node-connect", "--url")
+	if NeedsPortForward() {
+		t.Skipf("test is broken for port-forwarded drivers: https://github.com/kubernetes/minikube/issues/7383")
+	}
+	// docs: Run `minikube service` with a regular `--url` to make sure the HTTP endpoint URL of the service is printed
+	rr, err = Run(t, cmdContext)
+	if err != nil {
+		t.Errorf("failed to get service url. args: %q: %v", rr.Command(), err)
+	}
+
+	endpoint := strings.TrimSpace(rr.Stdout.String())
+	t.Logf("found endpoint for hello-node-connect: %s", endpoint)
 
 	// docs: Make sure we can hit the endpoint URL with an HTTP GET request
 	fetch := func() error {
@@ -1637,11 +1700,7 @@ func validateCpCmd(ctx context.Context, t *testing.T, profile string) {
 	testCpCmd(ctx, t, profile, "", srcPath, "", dstPath)
 
 	// copy from node
-	tmpDir, err := ioutil.TempDir("", "mk_test")
-	if err != nil {
-		t.Fatal(err)
-	}
-	defer os.RemoveAll(tmpDir)
+	tmpDir := t.TempDir()
 
 	tmpPath := filepath.Join(tmpDir, "cp-test.txt")
 	testCpCmd(ctx, t, profile, profile, dstPath, "", tmpPath)
@@ -1721,7 +1780,7 @@ func setupFileSync(ctx context.Context, t *testing.T, profile string) {
 	p := localSyncTestPath()
 	t.Logf("local sync path: %s", p)
 	syncFile := filepath.Join(*testdataDir, "sync.test")
-	err := copy.Copy(syncFile, p)
+	err := cp.Copy(syncFile, p)
 	if err != nil {
 		t.Fatalf("failed to copy testdata/sync.test: %v", err)
 	}
@@ -1730,7 +1789,7 @@ func setupFileSync(ctx context.Context, t *testing.T, profile string) {
 
 	// Write to a temp file for an atomic write
 	tmpPem := localTestCertPath() + ".pem"
-	if err := copy.Copy(testPem, tmpPem); err != nil {
+	if err := cp.Copy(testPem, tmpPem); err != nil {
 		t.Fatalf("failed to copy %s: %v", testPem, err)
 	}
 
@@ -1754,7 +1813,7 @@ func setupFileSync(ctx context.Context, t *testing.T, profile string) {
 
 	testPem2 := filepath.Join(*testdataDir, "minikube_test2.pem")
 	tmpPem2 := localTestCertFilesPath() + ".pem"
-	if err := copy.Copy(testPem2, tmpPem2); err != nil {
+	if err := cp.Copy(testPem2, tmpPem2); err != nil {
 		t.Fatalf("failed to copy %s: %v", testPem2, err)
 	}
 
@@ -2010,10 +2069,7 @@ func startProxyWithCustomCerts(ctx context.Context, t *testing.T) error {
 		}
 	}()
 
-	mitmDir, err := os.MkdirTemp("", "")
-	if err != nil {
-		return errors.Wrap(err, "create temp dir")
-	}
+	mitmDir := t.TempDir()
 
 	_, err = Run(t, exec.CommandContext(ctx, "tar", "xzf", "mitmproxy-6.0.2-linux.tar.gz", "-C", mitmDir))
 	if err != nil {
