@@ -1,5 +1,4 @@
 //go:build integration
-// +build integration
 
 /*
 Copyright 2016 The Kubernetes Authors All rights reserved.
@@ -59,16 +58,7 @@ func validateMountCmd(ctx context.Context, t *testing.T, profile string) { // no
 	}
 
 	t.Run("any-port", func(t *testing.T) {
-		tempDir, err := os.MkdirTemp("", "mounttest")
-		defer func() { // clean up tempdir
-			err := os.RemoveAll(tempDir)
-			if err != nil {
-				t.Errorf("failed to clean up %q temp folder.", tempDir)
-			}
-		}()
-		if err != nil {
-			t.Fatalf("Unexpected error while creating tempDir: %v", err)
-		}
+		tempDir := t.TempDir()
 
 		ctx, cancel := context.WithTimeout(ctx, Minutes(10))
 
@@ -208,16 +198,7 @@ func validateMountCmd(ctx context.Context, t *testing.T, profile string) { // no
 		}
 	})
 	t.Run("specific-port", func(t *testing.T) {
-		tempDir, err := os.MkdirTemp("", "mounttest")
-		defer func() { // clean up tempdir
-			err := os.RemoveAll(tempDir)
-			if err != nil {
-				t.Errorf("failed to clean up %q temp folder.", tempDir)
-			}
-		}()
-		if err != nil {
-			t.Fatalf("Unexpected error while creating tempDir: %v", err)
-		}
+		tempDir := t.TempDir()
 
 		ctx, cancel := context.WithTimeout(ctx, Minutes(10))
 
