@@ -1,5 +1,4 @@
 //go:build integration
-// +build integration
 
 /*
 Copyright 2020 The Kubernetes Authors All rights reserved.
@@ -36,6 +35,9 @@ import (
 
 // TestSkaffold makes sure skaffold run can be run with minikube
 func TestSkaffold(t *testing.T) {
+	if runtime.GOOS == "windows" {
+		t.Skip("skipping due to https://github.com/kubernetes/minikube/issues/14232")
+	}
 	if NoneDriver() {
 		t.Skip("none driver doesn't support `minikube docker-env`; skaffold depends on this command")
 	}
